==> nextcloud-26.0.10.tgz: nextcloud/apps/oauth2/l10n/es_EC.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Tu cliente no está autorizado para conectarse. Por favor, informa al administrador de tu cliente.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Tu URL de redirección debe ser una URL completa, por ejemplo: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite la autenticación compatible con OAuth2 desde otras aplicaciones web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "La aplicación OAuth2 permite a los administradores configurar el flujo de autenticación integrado para permitir la autenticación compatible con OAuth2 desde otras aplicaciones web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permite a servicios externos solicitar acceso a {instanceName}.",
    "Name" : "Nombre",
    "Redirection URI" : "URI para redirección",
    "Client Identifier" : "Identificador del cliente",
    "Secret key" : "Llave secreta",
    "Add client" : "Agregar cliente",
    "Add" : "Agregar",
    "Show client secret" : "Mostrar el secreto del cliente",
    "Delete" : "Borrar",
    "Secret" : "Secreto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.3.tgz: nextcloud/apps/oauth2/l10n/es_EC.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Tu cliente no está autorizado para conectarse. Por favor, informa al administrador de tu cliente.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Tu URL de redirección debe ser una URL completa, por ejemplo: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite la autenticación compatible con OAuth2 desde otras aplicaciones web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "La aplicación OAuth2 permite a los administradores configurar el flujo de autenticación integrado para permitir la autenticación compatible con OAuth2 desde otras aplicaciones web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permite a servicios externos solicitar acceso a {instanceName}.",
    "Add client" : "Agregar cliente",
    "Name" : "Nombre",
    "Redirection URI" : "URI para redirección",
    "Add" : "Agregar",
    "Client Identifier" : "Identificador del cliente",
    "Secret" : "Secreto",
    "Show client secret" : "Mostrar el secreto del cliente",
    "Delete" : "Borrar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
